@@ -17,38 +17,38 @@ kNN = function( formula, train, test, k = 1, transform = FALSE, l = 0,
 {
     formula = stats::as.formula( formula )
     
-    mf  = stats::model.frame( formula, data = train )
-    mt  = attr( mf, "terms" )
-    mt2 = stats::delete.response( mt )
+    model_frame_train  = stats::model.frame( formula, data = train )
+    model_train        = attr( model_frame_train, "terms" )
+    model_train_no_res = stats::delete.response( model_train )
     
-    cl = stats::model.response( mf )
+    train_label = stats::model.response( model_frame_train )
     
-    learn = stats::model.matrix( mt, mf    )[ , -1 ]
-    valid = stats::model.matrix( mt2, test )[ , -1 ]
+    train = stats::model.matrix( model_train, model_frame_train )[ , -1 ]
+    test  = stats::model.matrix( model_train_no_res, test )[ , -1 ]
     
     if( transform == TRUE ) transform = "minmax"
     
     if( transform != FALSE )
     {
-        if( !is.vector( learn ) ){
-            data_all = rbind( learn, valid )
+        if( !is.vector( train ) ){
+            data_all = rbind( train, test )
             data_all = liver::transform( data_all, method = transform )
             
-            learn = data_all[    1:nrow( learn )  , ]
-            valid = data_all[ -( 1:nrow( learn ) ), ]
+            train = data_all[    1:nrow( train )  , ]
+            test  = data_all[ -( 1:nrow( train ) ), ]
         }else{
-            data_all = c( learn, valid )
+            data_all = c( train, test )
             data_all = liver::transform( data_all, method = transform )
             
-            learn = data_all[    1:length( learn )   ]
-            valid = data_all[ -( 1:length( learn ) ) ]
+            train = data_all[    1:length( train )   ]
+            test  = data_all[ -( 1:length( train ) ) ]
         }
     }
     
-    class::knn( train = learn, test = valid, cl = cl, k = k, l = l, 
+    class::knn( train = train, test = test, cl = train_label, k = k, l = l, 
                 prob = prob, use.all = use.all )
 }
-    
+
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 
 
